Program Test;
{ $NOSHADOW}                                                                   // make this a comment, so that ALL registers get saved
{ $LCDNOINIT}              {user calls LCDsetup if desired}

{ $NOSAVE}
{ $WG}                     {global Warnings off} // activate for error.list and unused variables
{ $W+}                                           // activate for error.list and unused variables
{$TYPEDCONST OFF}             // so knnen Typdefinitionen in Const weggelassen werden... naja


Device = mega2561, VCC=5;


Define_Fuses                                                                    // Fuses hier zur Dokumentation angegeben. Nicht angegeben = 1 = NICHT gesetzt
  Override_Fuses;                                                               // Das funktioniert nicht wie im Compiler-Handbuch auf S. 52 beschrieben
  LockBits0      = [];
  FuseBits0      = [SUT1];                                                      // CKSEL3..1 = 111 --> 16 MHz external oscillator
                                                                                // CKSEL0 = 1, SUT1..0 = 01 --> Crystal oscillator, BOD enabled
  FuseBits1      = [SPIEN, EESAVE, BOOTSZ1];                                    // BOOTSZ1\SZ0 0 1 --> Bootloader at WORD ADDRESS $1F800, EESAVE --> EEPROM is preserved during a chip erase
  FuseBits2      = [BODLEVEL0,BODLEVEL2];                                       // Brown Out at 4.3V BL0: 1, BL1: 1, BL2: 0;     2.7V: BL0: 0, BL1: 1, BL2: 0
  ProgMode       = SPI;


Import SysTick, SerPort, LCDPort, I2CPort;

From System  Import Float;


Define
  ProcClock       = 14745600;       {Hertz}
  SysTick         = 10;             {msec}
  StackSize       = $0100, iData;
  FrameSize       = $0880, iData;

  I2Cport         = PortD;                                                      // use port PortD for the Soft-I2C
  I2Cclk          = 0, NOPs7;	                                                // Use PortD.0 for the SCL. The second number gives the # of P Cycles for one Clock:
                                                                                // With 14.745.600 Hz one cycle is ~ 67,8 nSec.
                                                                                // So:  36 x 67,8 nSec =  2,4408 Sec = 409 kHz   (for 400 kBit/Sec)
                                                                                // So: 148 x 67,8 nSec = 10,0344 Sec = 100 kHz   (for 100 kBit/Sec)
  I2Cdat          = 1;		                                                // Use PortD.1 for the SDA

  Serport         = 230400, Stop2; //, TimeOut; //921600 460800 230400 115200
  SerPortDTR      = PinF, 0, Negative;                                          // Input (CTS): Handshake from XPort to ATMega: Hi indicates ATMega STOP sending to XPort!
                                                                                // SerPortDTR can NOT be used in the program!!  On IFP: Middle LED
  SerPortDSR      = PortF, 1, Negative;                                         // Output(RTS): Handshake from ATMega to XPort: Hi indicates XPort STOP sending to ATMega!
                                                                                //                                              On IFP: Lowest LED
  RxBuffer        = 255, iData;     //128 96                                    // We made the primary RxBuffer a little bigger to avoid frequent CTS-signals
                                                                                // from the ATMega to the XPort
                                                                                // THIS BUFFER MUST BE BIGGER THAN DELPHI's TX BUFFER !!!
  TxBuffer        = 255, iData;     //32

  LCDType         = 0073;
  LCDRows         = 4;
  LCDColumns      = 20;
  LCDPort         = SPI_Soft, PortC, 0, 1, 2, 3;                                // PortX, SCK, MOSI, MISO, SS

Uses uTest  in 'uTest.pas';

Implementation

{$IDATA}
Const
   cISL1208RTC: Byte = $6F;                                                     // I2C Address of the RTC ISL1208: DeviceCode 1101 Adr. 111 : (0)110.1111 = $6F


{--------------------------------------------------------------}

{$EEPROM}


{$IDATA}
{ Var Declarations }
Var
   gByte : Byte;
   gInt  : Integer;
   LCDBacklightPower [@PortA,7] : Bit;

{--------------------------------------------------------------}
{ Main Program }
{$IDATA}

Function GetSecond : Byte;
Var
   lBy : Byte;
Begin
   I2COut(cISL1208RTC,0);                                                    // Select Register 00 (seconds) for reading
   I2CInp(cISL1208RTC,lBy);                                                  // Read the Seconds to lBy
   lBy := BCDToByte(lBy);
   Return (lBy);
End;


begin
                                                                                // PA0 = Input Voltage before the 2940 CT5 for sensing external Power supply

                                                                                // PA0 = O DCF77 LED New. 1 = Off, 0 = On            (New version Rev. K -..)
                                                                                // PA1 = O Power LED 0 = On, 1 = Off                 (New version Rev. K -..)
                                                                                // PA2 = O LCD Reset 0 = Reset, 1 = Normal Operation (New version Rev. K -..)
                                                                                // PA3 = O Analog Power. 0 = Off, 1 = On
                                                                                // PA4 = O Online LED. 1 = Off, 0 = On
                                                                                // PA5 = O Active/Idle LED, Green Anode.
                                                                                // PA6 = O Active/Idle LED, Red Anode.
                                                                                //         PA5 = 0, PA6 = 0 : Off.  PA5 = 1, PA6 = 0 : Green On.  PA5 = 0, PA6 = 1 : Red On.
                                                                                // PA7 = O LCD Backlight Power. 0 = LCD Off, 1 = LCD On
   DDRA  := %11111111;                                                          // DDRx : 0 is Input, 1 is Output. If 0 = Input: then PortX = 1 activates the internal pullup
   PortA := %01000100;                                                          // All Outputs Lo, All Inputs without Pullup

                                                                                // PC0 = O SCLK SPI for LCD
                                                                                // PC1 = O MOSI SPI for LCD
                                                                                // PC2 = I MISO SPI for LCD
                                                                                // PC3 = I Not used
                                                                                // PC4 = I Not used
                                                                                // PC5 = I Userkey
                                                                                // PC6 = I Sense MMC Write Protect
                                                                                // PC7 = I Not used
   DDRC  := %00001011;                                                          // DDRx : 0 is Input, 1 is Output. If 0 = Input: then PortX = 1 activates the internal pullup
   PortC := %11110100;                                                          // All Outputs Lo, All Inputs with Pullup

                                                                                // PD0 = I SCL IC Bus
                                                                                // PD1 = I SDA IC Bus
                                                                                // PD2, PD3 = I Not used
                                                                                // PD4 = I ICP1 Main multiplexed PWM Input from Input 1 .. 16 (see PA0)
                                                                                // PD5 - PD7 = I Not used
   DDRD  := %00000000;                                                          // DDRx : 0 is Input, 1 is Output. If 0 = Input: then PortX = 1 activates the internal pullup
   PortD := %00010000;                                                          // All Inputs without Pullup, except ICP1

   I2Cout($4F,1,$60);                                                           // Initialize the DS75 to $60 = 12 Bit, $40 = 11 Bit, $20 = 10 Bit, $00 = 9 Bit
   I2Cout($4F,0);


   I2COut(cISL1208RTC,$07,%00000000);                                           // Select Register 07 (Status) and Write to it: %0xxx disables the automatic Read-Delete of the BAT and ALM Bits
                                                                                //                                              %x0xx switches the internal Oscillator for the 32kHz Crystal on
                                                                                //                                              %xxx1 would enable the Writing to the RTC section - not used here
                                                                                //                                              %xxxx x0xx Reset the Alarm Bit
                                                                                //                                              %xxxx xx0x Reset the Battery Bit
   I2COut(cISL1208RTC,$08,%00110000);                                           // Select Register 08 (INT) and Write to it:    %0xxx Standard Alarm Output Mode
                                                                                //                                              %x0xx Switch off the Alarm function
                                                                                //                                              %001x Activate the Low Power Mode
                                                                                //                                              %xxx1 Frequency Output Pin is disabled during Battery mode

   EnableInts;
   SysTickEnable;

   LCDBacklightPower := 1;
   mDelay(100);

   LCDclr;                                                                      // clear display
   LCDcursor(false, false);                                                     // display on, cursor off & no blink
   LCDhome;                                                                     // cursor home

   I2COut(cISL1208RTC,$07,%00010000);                                           // Select Register 07 (Status) and Write to it: %0xxx disables the automatic Read-Delete of the BAT and ALM Bits
                                                                                //                                              %x0xx switches the internal Oscillator for the 32kHz Crystal on
                                                                                //                                              %xxx1 enables  the Writing to the RTC section
   gByte := ByteToBCD(17);
   I2COut(cISL1208RTC,0,gByte);                                                 // Select Register 00 (seconds) and Write the true Seconds into the Register now.

   loop
        I2COut(cISL1208RTC,0);                                                    // Select Register 00 (seconds) for reading
        I2CInp(cISL1208RTC,gByte);                                                // Read the Seconds to lBy
        gByte := BCDToByte(gByte);
        LCDxy(0,2);
        Write(LCDout, 'ID'+ByteToStr(gByte:2:'0') );
        mDelay(500);
   endloop;

{ $DEPHASE}
end Test.

